.. _sec-user_guide-data:

Data guide
==========

.. toctree::
   :maxdepth: 2

   intro
   absorption
   atmosphere_radprops
   atmosphere_thermoprops
   ckd
   particle_radprops
   solar_irradiance
   srf
